@@ -1,4 +1,4 @@
-use crate::minhash::{calculate_b_and_r, compute_minhash_distance, compute_minhash_similarity, minhash_band_centroid_from_refs, minhash_centroid};
+use crate::minhash::{calculate_b_and_r, compute_minhash_distance, compute_minhash_similarity, minhash_band_centroid_from_refs, minhash_centroid, MinHashType};
 use fxhash::FxBuildHasher;
 use fxhash::FxHashMap;
 use fxhash::FxHashSet;
@@ -26,17 +26,18 @@ gives free access to whole minhashes, and bands without sacrificing neither perf
 memory utilization.
  */
 
-struct BandKey<T: Hash + Eq> {
+
+struct BandKey<T: MinHashType> {
     v: *const T,
     len: usize,
 }
 
-unsafe impl<T: Hash + Eq> Send for BandKey<T> {}
-unsafe impl<T: Hash + Eq> Sync for BandKey<T> {}
+unsafe impl<T: MinHashType> Send for BandKey<T> {}
+unsafe impl<T: MinHashType> Sync for BandKey<T> {}
 
-impl<T: Hash + Eq> Eq for BandKey<T> {}
+impl<T: MinHashType> Eq for BandKey<T> {}
 
-impl<T: Hash + Eq> PartialEq for BandKey<T> {
+impl<T: MinHashType> PartialEq for BandKey<T> {
     fn eq(&self, other: &Self) -> bool {
         unsafe {
             for i in 0..self.len {
@@ -49,7 +50,7 @@ impl<T: Hash + Eq> PartialEq for BandKey<T> {
     }
 }
 
-impl<T: Hash + Eq> Hash for BandKey<T> {
+impl<T: MinHashType> Hash for BandKey<T> {
     fn hash<H: Hasher>(&self, state: &mut H)
     where
         T: Hash,
@@ -64,7 +65,7 @@ impl<T: Hash + Eq> Hash for BandKey<T> {
 
 struct MinHashBand<T, Id>
 where
-    T: Hash + Eq,
+    T: MinHashType,
     Id: Hash + Eq + Clone,
 {
     hash_table: FxHashMap<BandKey<T>, FxHashSet<Id>>,
@@ -75,7 +76,7 @@ where
 
 impl<T, Id> MinHashBand<T, Id>
 where
-    T: Hash + Eq,
+    T: MinHashType,
     Id: Hash + Eq + Clone,
 {
     pub fn new(band_start: isize, band_end: isize) -> Self {
@@ -275,7 +276,7 @@ where
 /// # Examples
 ///
 /// ```
-/// use gaoya::minhash::{MinHashIndex, MinHasher32V1, MinHasher} ;
+/// use gaoya::minhash::{MinHashIndex, MinHasher32, MinHasher} ;
 /// use gaoya::text::whitespace_split;
 /// use fxhash::FxHashSet;
 /// let corpus = [
@@ -285,7 +286,7 @@ where
 ///     "Is this the first document?",
 ///     "This not the first nor the second nor the third, but the fourth document"];
 /// let (num_bands, band_width) = (42, 3);
-/// let minhasher = MinHasher32V1::new(num_bands * band_width);
+/// let minhasher = MinHasher32::new(num_bands * band_width);
 /// let mut index = MinHashIndex::new(num_bands, band_width, 0.5);
 /// for (i, doc) in corpus.iter().enumerate() {
 ///     index.insert(i, minhasher.create_signature(whitespace_split(&doc.to_lowercase())));
@@ -306,7 +307,7 @@ where
 #[derive()]
 pub struct MinHashIndex<T, Id>
     where
-        T: Hash + Eq,
+        T: MinHashType,
         Id: Hash + Eq + Clone,
 {
     bands: Vec<MinHashBand<T, Id>>,
@@ -322,7 +323,7 @@ static REMOVED_KEYS_COUNT_CLEAN_TRIGGER: usize = 1000;
 
 impl<T, Id> fmt::Display for MinHashIndex<T, Id>
 where
-    T: Hash + Eq,
+    T: MinHashType,
     Id: Hash + Eq + Clone,
 {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
@@ -334,7 +335,7 @@ where
 
 impl<T, Id> MinHashIndex<T, Id>
 where
-    T: Hash + Eq + Copy,
+    T: MinHashType,
     Id: Hash + Eq + Clone,
 {
     /// Create a new MinHashIndex
@@ -607,11 +608,11 @@ where
     /// # Examples
     ///
     /// ```
-    /// use gaoya::minhash::{MinHasher,MinHasher16V1, MinHashIndex};
+    /// use gaoya::minhash::{MinHasher,MinHasher16, MinHashIndex};
     /// use gaoya::text::whitespace_split;
     ///
     /// let mut index = MinHashIndex::new(33, 3, 0.6);
-    /// let minhasher = MinHasher16V1::new(33 * 3);
+    /// let minhasher = MinHasher16::new(33 * 3);
     /// let signature1 = minhasher.create_signature(whitespace_split("This is the first minhashed document"));
     /// let signature2 = minhasher.create_signature(whitespace_split("This is the second minhashed document"));
     /// let query = signature1.clone();
@@ -759,7 +760,7 @@ where
 
 impl<T, Id> QueryIndex for MinHashIndex<T, Id>
     where
-        T: Hash + Eq + Copy,
+        T: MinHashType ,
         Id: Hash + Eq + Clone {
     type Id = Id;
 
@@ -776,13 +777,14 @@ impl<T, Id> QueryIndex for MinHashIndex<T, Id>
 
 #[cfg(test)]
 mod tests {
-    use crate::minhash::min_hash64::MinHasher64V1;
-    use crate::minhash::{calculate_b_and_r, calculate_minhash_params, MinHasher, MinHasher32V1, MinHashIndex};
+    use crate::minhash::min_hasher64::MinHasher64V1;
+    use crate::minhash::{calculate_b_and_r, calculate_minhash_params, MinHasher, MinHashIndex};
     use rand::distributions::{Distribution, Uniform};
     use rand::prelude::ThreadRng;
     use rand::{thread_rng, Rng};
     use std::borrow::Borrow;
     use fxhash::FxHashSet;
+    use crate::minhash::min_hasher::MinHasher32;
     use crate::text::whitespace_split;
 
     static S1: &'static str = "local sensitive hashing is cool";
@@ -830,7 +832,7 @@ mod tests {
             "And this is the third document.",
             "Is this the first document?",
             "This not the first nor the second nor the third, but the fourth document"];
-        let minhasher = MinHasher32V1::new(42 * 3);
+        let minhasher = MinHasher32::new(42 * 3);
         let mut index = MinHashIndex::new(42, 3, 0.5);
         for (i, doc) in corpus.iter().enumerate() {
             index.insert(i, minhasher.create_signature(whitespace_split(&doc.to_lowercase())));
